package fr.ippon.kafkaLatency.utils;

import org.apache.log4j.Logger;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.LongSummaryStatistics;

/**
 * IPPON 2018.
 */
public class UtilStats implements Serializable {

    private static final List<Long> lStep = Collections.synchronizedList(new ArrayList());
    private static final List<Long> lTotal = Collections.synchronizedList(new ArrayList());

    private final long step;
    private long total;
    private String benchName;

    private final static Logger logger = Logger.getLogger(UtilStats.class);

    public UtilStats(String benchName) {

        step = Integer.valueOf(Config.getProperty("stats.step"));
        total = Integer.valueOf(Config.getProperty("stats.total"));

        this.benchName = benchName;
    }

    public void treatStats(long millis) {
        synchronized (lStep) {
            lStep.add(millis);

            if (lStep.size() > (step - 1)) {
                LongSummaryStatistics stats = lStep.parallelStream()
                        .mapToLong((x) -> x)
                        .summaryStatistics();

                logger.info("Stats (" + benchName + ") : " + stats);
                lStep.clear();
            }

            lTotal.add(millis);
            if (lTotal.size() > (total - 1)) {
                LongSummaryStatistics stats = lTotal.parallelStream()
                        .mapToLong((x) -> x)
                        .summaryStatistics();

                logger.info("Stats total (" + benchName + ") : " + stats);

                lTotal.clear();
            }

        }
    }

}
